Struct WpContentTypeManagerV1
pub struct WpContentTypeManagerV1 { /* private fields */ }wayland and Linux only.Expand description
surface content type manager
This interface allows a client to describe the kind of content a surface will display, to allow the compositor to optimize its behavior for it.
Warning! The protocol described in this file is currently in the testing phase. Backward compatible changes may be added together with the corresponding interface version bump. Backward incompatible changes can only be done by creating a new major version of the extension.
This interface has no events.
Implementations
impl WpContentTypeManagerV1
impl WpContentTypeManagerV1
pub fn destroy(&self)
pub fn destroy(&self)
destroy the content type manager object
Destroy the content type manager. This doesn’t destroy objects created with the manager.
pub fn get_surface_content_type<U, D>(
&self,
surface: &WlSurface,
qh: &QueueHandle<D>,
udata: U,
) -> WpContentTypeV1
pub fn get_surface_content_type<U, D>( &self, surface: &WlSurface, qh: &QueueHandle<D>, udata: U, ) -> WpContentTypeV1
create a new content type object
Create a new content type object associated with the given surface.
Creating a wp_content_type_v1 from a wl_surface which already has one attached is a client error: already_constructed.